LruMap

Struct LruMap 

pub struct LruMap<K: PartialEq, V, const S: usize> { /* private fields */ }
The LruMap (i.e. Least Recently Used Map) is a map of keys to values, with a fixed capacity. Adding keys beyond the capacity will remove the least recently accessed key-value tuple and return it.

Implementations

Source

impl<K: PartialEq, V, const S: usize> LruMap<K, V, S>

pub const fn new() -> Self

Create a new LruMap

pub fn insert(&mut self, key: K, value: V) -> Option<(K, V)>

Insert a new entry to the cache, and evict the least recently used one if capacity has been reached

pub fn get(&mut self, key: &K) -> Option<&V>

Get the value by key if it exists

If you need a mutable reference, you can use “as_mut”

pub fn get_least_recently_used(&mut self) -> Option<(&mut K, &mut V)>

Returns None if there is still more capacity, or if there is no LRU.

pub fn capacity(&self) -> usize

Returns the capacity of the map

pub fn len(&self) -> usize

Returns the len of the map. Can be used to determine if you should use insert or get_least_recently_used